==> libDwm-0.8.6_source.tgz: libDwm-0.8.6/iosbuild.sh <==
#!/bin/bash

PLATFORMPATH="/Applications/Xcode.app/Contents/Developer/Platforms"
TOOLSPATH="/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin"
export IPHONEOS_DEPLOYMENT_TARGET="10.3"
pwd=`pwd`

findLatestSDKVersion()
{
    sdks=`ls $PLATFORMPATH/$1.platform/Developer/SDKs`
    arr=()
    for sdk in $sdks
    do
       arr[${#arr[@]}]=$sdk
    done

    # Last item will be the current SDK, since it is alpha ordered
    count=${#arr[@]}
    if [ $count -gt 0 ]; then
       sdk=${arr[$count-1]:${#1}}
       num=`expr ${#sdk}-4`
       SDKVERSION=${sdk:0:$num}
    else
       SDKVERSION="10.3"
    fi
}

buildit()
{
    target=$1
    hosttarget=$1
    platform=$2

    if [[ $hosttarget == "arm64" ]]; then
        hosttarget="arm"
#    elif [[ $hosttarget == "x86_64" ]]; then
#        hosttarget="i386"
    fi

    export CXX="$(xcrun -sdk iphoneos -find clang++)"
    export CPP="$CXX -E"
    export CXXFLAGS="-arch ${target} -isysroot $PLATFORMPATH/$platform.platform/Developer/SDKs/$platform$SDKVERSION.sdk -miphoneos-version-min=$SDKVERSION"
    export AR=$(xcrun -sdk iphoneos -find ar)
    export RANLIB=$(xcrun -sdk iphoneos -find ranlib)
    export CPPFLAGS="-arch ${target}  -isysroot $PLATFORMPATH/$platform.platform/Developer/SDKs/$platform$SDKVERSION.sdk -miphoneos-version-min=$SDKVERSION"
    export LDFLAGS="-arch ${target} -isysroot $PLATFORMPATH/$platform.platform/Developer/SDKs/$platform$SDKVERSION.sdk"
    export PLATFORM="$platform"
    mkdir -p $pwd/output/$target

    echo ./configure --prefix="$pwd/output/$target" --host=$hosttarget-apple-darwin
    ./configure --prefix="$pwd/output/$target" --host=$hosttarget-apple-darwin

    make clean
    make -j7
    make install
}

findLatestSDKVersion iPhoneOS

buildit armv7 iPhoneOS
buildit armv7s iPhoneOS
buildit arm64 iPhoneOS
buildit i386 iPhoneSimulator
buildit x86_64 iPhoneSimulator

LIPO=$(xcrun -sdk iphoneos -find lipo)
$LIPO -create $pwd/output/armv7/lib/libDwm.a  $pwd/output/armv7s/lib/libDwm.a $pwd/output/arm64/lib/libDwm.a $pwd/output/x86_64/lib/libDwm.a $pwd/output/i386/lib/libDwm.a -output libDwm.a

==> libDwm-0.9.4_source.tgz: libDwm-0.9.4/iosbuild.sh <==
#!/bin/bash

PLATFORMPATH="/Applications/Xcode.app/Contents/Developer/Platforms"
TOOLSPATH="/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin"
export IPHONEOS_DEPLOYMENT_TARGET="14.3"
pwd=`pwd`

findLatestSDKVersion()
{
    sdks=`ls $PLATFORMPATH/$1.platform/Developer/SDKs`
    arr=()
    for sdk in $sdks
    do
       arr[${#arr[@]}]=$sdk
    done

    # Last item will be the current SDK, since it is alpha ordered
    count=${#arr[@]}
    if [ $count -gt 0 ]; then
       sdk=${arr[$count-1]:${#1}}
       num=`expr ${#sdk}-4`
       SDKVERSION=${sdk:0:$num}
    else
       SDKVERSION="10.3"
    fi
}

buildit()
{
    target=$1
    hosttarget=$1
    platform=$2

    if [[ $hosttarget == "arm64" ]]; then
        hosttarget="arm"
#    elif [[ $hosttarget == "x86_64" ]]; then
#        hosttarget="i386"
    fi

    export CXX="$(xcrun -sdk iphoneos -find clang++)"
    export CPP="$CXX -E"
    export CXXFLAGS="-arch ${target} -isysroot $PLATFORMPATH/$platform.platform/Developer/SDKs/$platform$SDKVERSION.sdk -miphoneos-version-min=$SDKVERSION"
    export AR=$(xcrun -sdk iphoneos -find ar)
    export RANLIB=$(xcrun -sdk iphoneos -find ranlib)
    export CPPFLAGS="-arch ${target}  -isysroot $PLATFORMPATH/$platform.platform/Developer/SDKs/$platform$SDKVERSION.sdk -miphoneos-version-min=$SDKVERSION"
    export LDFLAGS="-arch ${target} -isysroot $PLATFORMPATH/$platform.platform/Developer/SDKs/$platform$SDKVERSION.sdk"
    export PLATFORM="$platform"
    mkdir -p $pwd/output/$target

    echo ./configure --prefix="$pwd/output/$target" --host=$hosttarget-apple-darwin
    ./configure --prefix="$pwd/output/$target" --host=$hosttarget-apple-darwin

    make clean
    make -j7
    make install
}

findLatestSDKVersion iPhoneOS

# buildit armv7 iPhoneOS
# buildit armv7s iPhoneOS
buildit arm64 iPhoneOS
# buildit i386 iPhoneSimulator
buildit x86_64 iPhoneSimulator

LIPO=$(xcrun -sdk iphoneos -find lipo)
$LIPO -create $pwd/output/arm64/lib/libDwm.a $pwd/output/x86_64/lib/libDwm.a -output libDwm.a
